/**
 * [BSD Open Source License]
 *
 * Copyright (c) 2006, Mattias Jiderhamn, Expert Systems
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or othermaterials provided with the distribution.
 *
 * Neither the name of Expert Systems nor the names of its contributors may
 * be usedto endorse or promote products derived from this software without
 * specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package se.expertsystem.intellij;

import com.intellij.openapi.actionSystem.ToggleAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.DataConstants;
import com.intellij.openapi.project.Project;

/**
 * Abstrac base class for actions that toggle a <code>ToggledProjectComponent</code>
 * @author Mattias Jiderhamn, mattias.jiderhamn@expertsystems.se
 */
public abstract class AbstractToggleAction extends ToggleAction {

  // private static final Logger LOG = Logger.getInstance(ToggleAWAction.class.getName());
  
  private final Class/*<ToggledProjectComponent>*/ componentClass;
  
  protected AbstractToggleAction(Class componentClass) {
    this.componentClass = componentClass;
  }

  /** Check if project component is activated */
  public boolean isSelected(AnActionEvent event) {
    Project currentProject = (Project) event.getDataContext().getData(DataConstants.PROJECT);
    if (currentProject != null && currentProject.hasComponent(componentClass)) {
      ToggledProjectComponent component = (ToggledProjectComponent)currentProject.getComponent(componentClass);
      return component.isActivated();
    }
    return false;
  }

  /** Change state of project component */
  public void setSelected(AnActionEvent event, boolean selected) {
    Project currentProject = (Project) event.getDataContext().getData(DataConstants.PROJECT);
    if (currentProject != null && currentProject.hasComponent(componentClass)) {
      ToggledProjectComponent component = (ToggledProjectComponent)currentProject.getComponent(componentClass);
      component.changeTo(selected);
    }
  }
}