/**
 * [BSD Open Source License]
 *
 * Copyright (c) 2006, Mattias Jiderhamn, Expert Systems
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or othermaterials provided with the distribution.
 *
 * Neither the name of Expert Systems nor the names of its contributors may
 * be usedto endorse or promote products derived from this software without
 * specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package se.expertsystem.intellij;

import com.intellij.openapi.compiler.FileProcessingCompiler;
import com.intellij.openapi.compiler.ValidityState;
import com.intellij.openapi.compiler.TimestampValidityState;
import com.intellij.openapi.vfs.VirtualFile;

/**
 * Implementation of ProcessingItem used by post processing compiler 
 * @author Mattias Jiderhamn
 */
public class PostCompileProcessingItem implements FileProcessingCompiler.ProcessingItem {
  /** The compiled class file */
  private VirtualFile file;
  
  /** The package of the class */
  private String packagePrefix;
  
  /** The source file */
  private VirtualFile sourceFile;

  public PostCompileProcessingItem(VirtualFile file, String packagePrefix, VirtualFile sourceFile) {
    this.file = file;
    this.packagePrefix = packagePrefix;
    this.sourceFile = sourceFile;
  }

  /** Get the .class file */
  public VirtualFile getFile() {
    return file;
  }

  /** Get the package of the class */
  public String getPackagePrefix() {
    return packagePrefix;
  }

  /** Get the source (.java) file */
  public VirtualFile getSourceFile() {
    return sourceFile;
  }

  public ValidityState getValidityState() {
    return new TimestampValidityState(file.getModificationStamp());
  }
}