/**
 * [BSD Open Source License]
 *
 * Copyright (c) 2006, Mattias Jiderhamn, Expert Systems
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or othermaterials provided with the distribution.
 *
 * Neither the name of Expert Systems nor the names of its contributors may
 * be usedto endorse or promote products derived from this software without
 * specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package se.expertsystem.intellij;

import com.intellij.openapi.compiler.TranslatingCompiler;
import com.intellij.openapi.vfs.VirtualFile;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

/**
 * Sink wrapper to get access to the recently compiled files.
 *
 * @author mario@ops.co.at - invented in ebean-weaver plugin and granted permission to copy this class over to the aspectj weaver plugin.
 */
public class RecentlyCompiledSink implements TranslatingCompiler.OutputSink
{
	private final TranslatingCompiler.OutputSink delegate;

	private final List<CompiledItem> compiledItems = new ArrayList<CompiledItem>();

	public static class CompiledItem
	{
		private final String outputRoot;
		private final String outputPath;
		private final VirtualFile sourceFile;

		private CompiledItem(String outputRoot, String outputPath, VirtualFile sourceFile)
		{
			this.outputRoot = outputRoot;
			this.outputPath = outputPath;
			this.sourceFile = sourceFile;
		}

		public String getOutputRoot()
		{
			return outputRoot;
		}

		public String getOutputPath()
		{
			return outputPath;
		}

		public VirtualFile getSourceFile()
		{
			return sourceFile;
		}
	}

	public RecentlyCompiledSink(TranslatingCompiler.OutputSink delegate)
	{
		this.delegate = delegate;
	}

	public void add(String outputRoot, Collection<TranslatingCompiler.OutputItem> items, VirtualFile[] filesToRecompile)
	{
		if (items != null && outputRoot != null)
		{
			for (TranslatingCompiler.OutputItem item : items)
			{
				if (item.getOutputPath() == null)
				{
					continue;
				}
				
				compiledItems.add(new CompiledItem(outputRoot, item.getOutputPath(), item.getSourceFile()));
			}
		}

		if (delegate != null)
		{
			delegate.add(outputRoot, items, filesToRecompile);
		}
	}

	public List<CompiledItem> getCompiledItems()
	{
		return compiledItems;
	}
}
